View source: R/km_wlr_calculations_helpers.R
| KM_estimates | R Documentation |
Computes Kaplan-Meier survival estimates and their variances given risk and event counts.
KM_estimates(ybar, nbar, sig2w_multiplier = NULL)
ybar |
Vector of risk set sizes at each time point. |
nbar |
Vector of event counts at each time point. |
sig2w_multiplier |
Optional vector for variance calculation. If NULL, calculated internally. |
List with survival estimates and variances.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.