Calculate risk set and event counts at time points
Source:R/df_counting_helpers.R
calculate_risk_event_counts.RdCalculates risk set and event counts for a group at specified time points, with variance estimation.
R/df_counting_helpers.R
calculate_risk_event_counts.RdCalculates risk set and event counts for a group at specified time points, with variance estimation.