get_event_risk_matrices: Event and Risk Matrices for Survival Analysis

View source: R/km_wlr_calculations_helpers.R

get_event_risk_matricesR Documentation

Event and Risk Matrices for Survival Analysis

Description

Constructs matrices indicating event and risk status for each subject at specified time points.

Usage

get_event_risk_matrices(U, at.points)

Arguments

U

Vector of observed times (e.g., time-to-event).

at.points

Vector of time points at which to evaluate events and risk.

Value

A list with event and risk matrices.


weightedsurv documentation built on Dec. 23, 2025, 1:07 a.m.