Plot confidence interval polygon for KM curve
Source:R/kmplotting_helpers.R
plot_km_confint_polygon.RdPlots a shaded polygon representing the confidence interval for a Kaplan-Meier survival curve.
R/kmplotting_helpers.R
plot_km_confint_polygon.RdPlots a shaded polygon representing the confidence interval for a Kaplan-Meier survival curve.