ci_cox: Confidence interval for Cox model estimate

View source: R/weightedCox.R

ci_coxR Documentation

Confidence interval for Cox model estimate

Description

Calculates the confidence interval for a Cox model log hazard ratio estimate.

Usage

ci_cox(bhat, sig_bhat, alpha = 0.05, verbose = FALSE)

Arguments

bhat

Estimated log hazard ratio.

sig_bhat

Standard error of the estimate.

alpha

Significance level (default: 0.05).

verbose

Logical; if TRUE, prints interval.

Value

Data frame with log hazard ratio, standard error, hazard ratio, lower and upper confidence limits.


weightedsurv documentation built on Dec. 23, 2025, 1:07 a.m.