| ci_cox | R Documentation |
Calculates the confidence interval for a Cox model log hazard ratio estimate.
ci_cox(bhat, sig_bhat, alpha = 0.05, verbose = FALSE)
bhat |
Estimated log hazard ratio. |
sig_bhat |
Standard error of the estimate. |
alpha |
Significance level (default: 0.05). |
verbose |
Logical; if TRUE, prints interval. |
Data frame with log hazard ratio, standard error, hazard ratio, lower and upper confidence limits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.