Extract time, event, and weight data for a group
Source:R/df_counting_helpers.R
extract_group_data.RdExtracts time, event, and weight vectors for a specified group.
R/df_counting_helpers.R
extract_group_data.RdExtracts time, event, and weight vectors for a specified group.