View source: R/km_wlr_calculations_helpers.R
| get_event_risk_matrices | R Documentation |
Constructs matrices indicating event and risk status for each subject at specified time points.
get_event_risk_matrices(U, at.points)
U |
Vector of observed times (e.g., time-to-event). |
at.points |
Vector of time points at which to evaluate events and risk. |
A list with event and risk matrices.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.