validate_scheme_params: Validate weighting scheme parameters

View source: R/weighted_helpers.R

validate_scheme_paramsR Documentation

Validate weighting scheme parameters

Description

Checks and validates the parameters for a given weighting scheme.

Usage

validate_scheme_params(scheme, scheme_params, S.pool)

Arguments

scheme

Character string specifying the weighting scheme.

scheme_params

List of parameters for the scheme.

S.pool

Numeric vector of pooled survival probabilities.

Value

Logical indicating if parameters are valid, or stops with error.


weightedsurv documentation built on Dec. 23, 2025, 1:07 a.m.