View source: R/weighted_helpers.R
| validate_scheme_params | R Documentation |
Checks and validates the parameters for a given weighting scheme.
validate_scheme_params(scheme, scheme_params, S.pool)
scheme |
Character string specifying the weighting scheme. |
scheme_params |
List of parameters for the scheme. |
S.pool |
Numeric vector of pooled survival probabilities. |
Logical indicating if parameters are valid, or stops with error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.