View source: R/km_wlr_calculations_helpers.R
| wlr_dhat_estimates | R Documentation |
Computes the weighted log-rank statistic, its variance, the difference in survival at a specified time (tzero),
the variance of the difference, their covariance, and correlation, using flexible time-dependent weights.
The weighting scheme is selected via the scheme argument and is calculated using wt.rg.S.
wlr_dhat_estimates(
dfcounting,
scheme = "fh",
scheme_params = list(rho = 0, gamma = 0),
tzero = NULL
)
dfcounting |
List output from |
scheme |
Character string specifying weighting scheme. One of: "fh" (Fleming-Harrington), "schemper", "XO", "MB", "custom_time", or "custom_code". |
scheme_params |
Named list with numeric weighting parameters |
tzero |
Time point at which to evaluate the difference in survival (default: 24). |
The weighting scheme is selected via the scheme argument and calculated using wt.rg.S.
Supports standard Fleming-Harrington, Schemper, XO (Xu & O'Quigley), MB (Maggir-Burman), custom time-based, and custom code weights.
A list with elements:
lr |
Weighted log-rank test statistic. |
sig2_lr |
Variance of the log-rank statistic. |
dhat |
Difference in survival at |
cov_wlr_dhat |
Covariance between log-rank and difference at |
sig2_dhat |
Variance of the difference at |
cor_wlr_dhat |
Correlation between log-rank and difference at |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.